## 任务类型(Task Type)
SPN专线投诉诊断

## 任务描述(Task Description)
要求：提供任务的整体概述，基于<任务对象>、<任务上下文>、<约束条件>进行投诉场景的网络侧故障根因诊断，达成<任务目标>中定义的投诉诊断目标，按照<预期输出>中定义的结构返回任务处理结果。

## 任务目标(Task Target)
要求：
1. 基于专线业务的故障现象，诊断并返回网络侧的故障根因

## 任务对象(Task Object)
{{任务对象}}（可选）
要求：提供专线业务对象，以下 专线名称，接入端口名称，接入端口资源ID参数，3个参数下发其中一个参数用于标识专线业务对象
- 专线名称：网络侧EMS网管的专线对象标识
- 接入端口名称：网络侧EMS网管的接入端口名称，格式为：网元名称+单板号+单板型号+端口号
- 接入端口资源ID：网络侧EMS网管的接入段口资源对象标识
样例： 
接入端口资源ID：f47ac10b-58cc-4372-a567-0e02b2c3d479

## 任务上下文(Task Context)
{{任务上下文}}（必选）
要求：提供专线业务的故障现象描述和诊断任务的上下文信息
1. 故障现象：包含“专线中断”和“专线质量差”两种场景，必选参数。举例：”专线中断“
2. 故障发生时间，可选参数。举例：“2024-01-16T08:21:46Z”
3. OSS侧的故障或者事件流水号，可选参数。举例：“fault-id-1-017-20230511-09013”

## 预期输出(Expected Output)
{{预期输出}}（可选）
要求：
1. 包含诊断结果类型，诊断结果详细信息，修复建议
2. 诊断结果类型参数的取值范围包括：诊断成功、诊断失败、诊断未开始或者诊断未结束
3. 可以包括多个故障根因，每个故障根因包含：故障根因的名称、详细描述、修复建议，故障根因点所在资源对象的标识、类型、名称、详细位置等信息。故障整体的详细描述，故障根因的修复建议。
4. 如果存在多故障根因，需要对多个故障根因中的详细描述和修复建议总结提炼到总体的诊断结果详情和修复建议中。